@@ -21,6 +21,21 @@ def k_folds_split(df : pd.DataFrame,
                   k : int, 
                   ) -> dict: 
 
+    '''
+    Return a dictionary of lists of DataFrames and Series for target
+    with next structure:
+
+    k_fold_dict = { 
+                    'train_X' : [train_df_0, train_df_1, ... , train_df_k],
+                    'test_X'  : [etc.], 
+                    'train_y' : [series_0, series_1, ... , series_k],
+                    'test_y'  : [etc.],
+                    }
+
+    Use case:
+    k_fold_dict_data = Snaplib().k_folds_split(df, target_name, k)
+    '''
+
     if not isinstance(df, pd.core.frame.DataFrame):
         raise TypeError('The df must be a pandas.core.frame.DataFrame instance.')
     if type(target_name) != str:
@@ -66,6 +81,30 @@ def train_test_split_balanced(  df : pd.DataFrame,
                                 research : bool, 
                                 ) -> tuple:
 
+    ''' 
+    Split the data with the distribution as close as possible 
+    to the same in both the train set and the test set, and not only for the target column, 
+    but also for all other columns.
+
+    Use case:
+    train_X, test_X, train_y, test_y = Snaplib().train_test_split_balanced(df, target_name, test_size=0.2, random_state=0, research=True)
+
+    1) The input should be a whole DataFrame. It's the first positional argument.
+    2) And the second positional argument should be the name of the target feature as a string.
+    3) This method has internal testing.
+    In this way you can testing the usefulness of the custom split.
+    The first test performing with a random_state values from 0 to 1/test_size by sklearn.model_selection.train_test_split.
+    Before split performing a final testing with Snaplib().train_test_split_balanced.
+
+    You can perform testing by specifying the value of the research argument = True.
+
+    4) If you are convinced that the method is useful. You can silence the method.
+    Set the research argument to False.
+
+    5) The number of possible random_state is an equivalent to 1/test_size.
+
+    TESTS on https://www.kaggle.com/artyomkolas/train-test-split-balanced-custom-in-snaplib/notebook
+    '''
 
     if not isinstance(df, pd.core.frame.DataFrame):
         raise TypeError('The df must be a pandas.core.frame.DataFrame instance.')
